@@ -2,8 +2,8 @@
 import logging
 import pika
 from pika import credentials
-from formatters import JSONFormatter
-from filters import FieldFilter
+from .formatters import JSONFormatter
+from .filters import FieldFilter
 
 
 class RabbitMQHandler(logging.Handler):
@@ -48,7 +48,8 @@ class RabbitMQHandler(logging.Handler):
         # Allow extra params when connect to RabbitMQ.
         # @see: http://pika.readthedocs.io/en/0.10.0/modules/parameters.html#pika.connection.ConnectionParameters
         conn_params = connection_params if isinstance(connection_params, dict) else {}
-        self.connection_params = dict(conn_params.items() + dict(host=host, port=port, heartbeat_interval=0).items())
+        self.connection_params = conn_params.copy()
+        self.connection_params.update(dict(host=host, port=port, heartbeat_interval=0))
 
         if username and password:
             self.connection_params['credentials'] = credentials.PlainCredentials(username, password)
